/****************************************************************
Copyright (c) 1998 Sandro Sigala <ssigala@globalnet.it>.
All rights reserved.

Permission to use, copy, modify, and distribute this software
and its documentation for any purpose and without fee is hereby
granted, provided that the above copyright notice appear in all
copies and that both that the copyright notice and this
permission notice and warranty disclaimer appear in supporting
documentation, and that the name of the author not be used in
advertising or publicity pertaining to distribution of the
software without specific, written prior permission.

The author disclaim all warranties with regard to this
software, including all implied warranties of merchantability
and fitness.  In no event shall the author be liable for any
special, indirect or consequential damages or any damages
whatsoever resulting from loss of use, data or profits, whether
in an action of contract, negligence or other tortious action,
arising out of or in connection with the use or performance of
this software.
****************************************************************/

#include "config.h"

#include <qframe.h>
#include <qpixmap.h>
#include <qpainter.h>
#include <qimage.h>

#include "kreptoned.h"
#include "spritegridframe.h"

SpriteGridFrame::SpriteGridFrame(QPixmap *xsprites, QWidget *parent, const char *name)
	: QFrame(parent, name)
{
	sprites = xsprites;
	setFrameStyle(Box | Raised);
	setLineWidth(2);
	setMidLineWidth(1);
	border = lineWidth() * 2 + midLineWidth();
	resize(sprite_width * 8 + border*2-1,
	       sprite_height * 8 + border*2-1);
	setMouseTracking(true);
}

void SpriteGridFrame::drawContents(QPainter *p)
{
	QImage img = sprites[current_sprite].convertToImage();
	for (int y = 0; y < sprite_height; ++y)
		for (int x = 0; x < sprite_width; ++x) {
			QColor c = img.pixel(x, y);
			p->fillRect(border + x * 8, border + y * 8,
				    7, 7, c);
		}
}

void SpriteGridFrame::mousePressEvent(QMouseEvent *e)
{
	if (e->button() == LeftButton || e->button() == RightButton) {
		if (e->x() < border || e->x() > width() - border
		    || e->y() < border || e->y() > height() - border)
			return;
		int x = (e->x() - border)/8;
		int y = (e->y() - border)/8;
		emit pressedButton(e->button(), x, y);
	}
}

void SpriteGridFrame::mouseMoveEvent(QMouseEvent *e)
{
	if (e->x() < border || e->x() > width() - border
	    || e->y() < border || e->y() > height() - border)
		return;

	int x = (e->x() - border)/8;
	int y = (e->y() - border)/8;

	if (e->state() & (LeftButton|RightButton))
		emit pressedButton(e->state() & (LeftButton|RightButton), x, y);

	emit changedCoordinates(x, y);
}
